﻿using Dapper;
using Microsoft.Extensions.Logging;
using Newtonsoft.Json;
using ShoeStore.Entities;
using System;
using System.Collections.Generic;
using System.Data.SqlClient;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ShoeStore.Repositories.Implementations;

internal class ShoesSaleRepository : IShoesSaleRepository
{
    private readonly IConnectionString _connectionString;
    private readonly ILogger<ShoesSaleRepository> _logger;
    public ShoesSaleRepository(IConnectionString connectionString,
    ILogger<ShoesSaleRepository> logger)
    {
        _connectionString = connectionString;
        _logger = logger;
    }
    public void CreateShoesSale(ShoesSale shoesSale)
    {
        _logger.LogInformation("Добавление объекта");
        _logger.LogDebug("Объект: {json}",
        JsonConvert.SerializeObject(shoesSale));
        try
        {
            using var connection = new
            SqlConnection(_connectionString.ConnectionString);
            var queryInsert = @"
INSERT INTO ShoesSales (ShoesId, FactoryId, StoreId, SaleDate, Specificity)
VALUES (@ShoesId, @FactoryId, @StoreId, @SaleDate, @Specificity)";
            connection.Execute(queryInsert, shoesSale);
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при добавлении объекта");
            throw;
        }
    }
    public IEnumerable<ShoesSale> ReadShoesSales(DateTime? dateForm =
    null, DateTime? dateTo = null, int? shoesId = null, int? factoryId = null, int?
    storeId = null)
    {
        _logger.LogInformation("Получение всех объектов");
        try
        {
            using var connection = new
            SqlConnection(_connectionString.ConnectionString);
            var querySelect = "SELECT * FROM ShoesSales";
            var shoesSales =
            connection.Query<ShoesSale>(querySelect);
            _logger.LogDebug("Полученные объекты: {json}",
            JsonConvert.SerializeObject(shoesSales));
            return shoesSales;
        }
        catch (Exception ex)
        {
            _logger.LogError(ex, "Ошибка при чтении объектов");
            throw;
        }
    }
}
